@@ -2,15 +2,15 @@
 ;;; <plaintext>
 ;;; revive.el: Resume Emacs.
 ;;; (c) 1994-2003 by HIROSE Yuuji [yuuji@gentei.org]
-;;; $Id: revive.el,v 2.18 2003/06/22 05:11:46 yuuji Exp $
-;;; Last modified Sun Jun 22 14:11:22 2003 on firestorm
+;;; $Id: revive.el,v 2.18 2003/06/22 05:11:46 yuuji Exp yuuji $
+;;; Last modified Fri May  6 11:54:46 2005 on firestorm
 
 ;;;[[[   NOTICE  NOTICE  NOTICE  NOTICE  NOTICE    ]]]
 ;;;--------------------------------------------------------------------------
 ;;;	If you are using `windows.el', you can omit the settings of
 ;;;	define-key and autoload.
-;;;	windows.elʻȤäƤ revive.el ΤΥγ
-;;;	Ƥautoload⤹ɬפޤ
+;;;	windows.el𕁒igĂꍇ revive.el ̂߂̃L[̊蓖
+;;;	Ăautoload̐ݒKv܂B
 ;;;--------------------------------------------------------------------------
 ;;;
 ;;;		Resume Emacs:		revive.el
@@ -135,98 +135,98 @@
 ;;;
 ;;; Japanese Document follows:
 ;;;
-;;;reviveȤϡ
+;;;yreviveƂ́z
 ;;;
-;;;	  revive.el ȤȡEmacs ѻξ֤ե˥֤ơ
-;;;	 Emacs ưˤξ֤뤳ȤǤޤ
-;;;	󥦥ɥʬ֤Τ saveconf  desktop 
-;;;	餤餷Ƥͤˤ⤪Ǥ
+;;;	  revive.el gƁAEmacs gp̏Ԃt@CɃZ[uāA
+;;;	 Emacs N鎞ɂ̏ԂɕA邱Ƃł܂B
+;;;	EBhE̕Ԃ̂ saveconf  desktop 
+;;;	炢炵Ălɂ߂łB
 ;;;
-;;;Ȥ߹
+;;;ygݍݕz
 ;;;
-;;;	  revive.el  load-path ̤äǥ쥯ȥ졢~/.emacs 
-;;;	ʲεҤƤ
+;;;	  revive.el  load-path ̒ʂfBNgɓA~/.emacs 
+;;;	ȉ̋LqĂB
 ;;;
 ;;;	  (autoload 'save-current-configuration "revive" "Save status" t)
 ;;;	  (autoload 'resume "revive" "Resume Emacs" t)
 ;;;	  (autoload 'wipe "revive" "Wipe emacs" t)
 ;;;
-;;;	ƾδؿ򹥤ʥ˳ƤƤʲǤ
+;;;	ď̊֐DȃL[Ɋ蓖ĂĂBȉ͗łB
 ;;;
 ;;;	  (define-key ctl-x-map "S" 'save-current-configuration)
 ;;;	  (define-key ctl-x-map "F" 'resume)
 ;;;	  (define-key ctl-x-map "K" 'wipe)
 ;;;
-;;;ڻȤ
+;;;ygz
 ;;;
-;;;	   define-key 򤷤ˤϡC-x S ǸߤԽ֤򥻡
-;;;	뤳ȤǤޤsave-current-configuration ؿ˿
-;;;	ʣξ̡֤˥֤ǤޤC-u 2 C-x SפȤ2
-;;;	֤ΥХåե˸򥻡֤ǤޤɤƱͤ
-;;;	C-u 2 C-x Fפȥפ2֤ΥХåե֤ɤޤ
+;;;	   define-key ꍇɂ́AC-x S Ō݂̕ҏWԂZ[u
+;;;	邱Ƃł܂Bsave-current-configuration ֐ɐ
+;;;	ƕ̏ԂʁXɃZ[uł܂BuC-u 2 C-x SvƂ2
+;;;	Ԃ̃obt@ɌZ[uł܂B[h鎞l
+;;;	uC-u 2 C-x Fvƃ^Cv2Ԃ̃obt@Ԃ[h܂B
 ;;;
-;;;ѿΥ֡
+;;;yϐ̃Z[uz
 ;;;
-;;;	  ѿͤ⥻֤ƤȤǤޤǥեȤǥ֤ 
-;;;	global ѿ revive:save-variables-global-default ˡlocal 
-;;;	 revive:save-variables-local-default Ƥޤ
-;;;	ѿ¸ϡrevive:save-variables-global-private 
-;;;	 global ѿ̾revive:save-variables-local-private  local 
-;;;	ѿ̾򤽤줾ꥹȤηƤޤ㤨 gmhist Ȥ
-;;;	Ƥˤϡ
+;;;	  ϐ̒lZ[uĂƂł܂BftHgŃZ[u 
+;;;	global ϐ revive:save-variables-global-default ɁAlocal 
+;;;	 revive:save-variables-local-default ɒ`Ă܂B
+;;;	̕ϐۑꍇ́Arevive:save-variables-global-private 
+;;;	 global ϐArevive:save-variables-local-private  local 
+;;;	ϐꂼꃊXǧ`Œ`Ă܂BႦ gmhist g
+;;;	Ăꍇɂ́A
 ;;;
 ;;;		(setq revive:save-variables-global-private
 ;;;		      '(file-history buffer-history minibuffer-history))
 ;;;
-;;;	ʤɤ ~/.emacs ˽񤤤ƤȲŬǤ礦
+;;;	Ȃǂ ~/.emacs ɏĂƉKł傤B
 ;;;
-;;;̤ǤʤХåեΰ
+;;;yʂłȂobt@̈z
 ;;;
-;;;	  mh-rmail ǤϥȥХåե mh-folder-mode, gnus Ǥϥ
-;;;	ȥХåե gnus-Group-mode ˤʤޤбطϡѿ 
-;;;	revive:major-mode-command-alist-default ˽񤫤Ƥޤ
-;;;	ϿƤʳΤΤϡ
+;;;	  mh-rmail ł̓Jgobt@ mh-folder-mode, gnus ł̓J
+;;;	gobt@ gnus-Group-mode ɂȂ܂B̑Ή֌ẂAϐ 
+;;;	revive:major-mode-command-alist-default ɏĂ܂B̕
+;;;	ɓo^ĂȊÔ̂`ꍇ́A
 ;;;
 ;;;		(setq revive:major-mode-command-alist-private
 ;;;		  '((hogehoge-mode	. hoge)
 ;;;		    (herohero-mode	. herohero)
-;;;		    ("ס˥塼"	. trr)))
+;;;		    ("^Cvj["	. trr)))
 ;;;
-;;;	Τ褦 revive:major-mode-command-alist-private ͤꤹ
-;;;	ȼ resume ˼ưŪб륳ޥɤưޤ
-;;;	ˤ褦ˡmajor-mode(ܥ) buffer-name
-;;;	(ʸ)ꤹ뤳ȤǤޤ
+;;;	̂悤 revive:major-mode-command-alist-private ̒lݒ肷
+;;;	Ǝ resume ɎIɑΉR}hN܂B
+;;;	̗ɂ悤ɁAmajor-mode(V{)̑ buffer-name
+;;;	()w肷邱Ƃł܂B
 ;;;
-;;;	  ޤSKKμΤ褦˥ꥸ塼हȤޤưʤʤäƤ
-;;;	ޤХåեϡѿ revive:ignore-buffer-pattern ˤ
-;;;	ΥХåե̾ޥå褦ɽꤷƤ
+;;;	  ܂ASKK̎̂悤ɃW[Ƃ܂ȂȂĂ
+;;;	܂obt@ꍇ́Aϐ revive:ignore-buffer-pattern ɂ
+;;;	̃obt@}b`悤ȐK\ݒ肵ĂB
 ;;;
-;;;ڥץफȤ
+;;;yvOgz
 ;;;
-;;;	  Ѹǥɥ [For programmers] ι򻲾ȤƤ
+;;;	  pŃhLg [For programmers] ̍QƂĂB
 ;;;
-;;;ڤȤ
+;;;yƂz
 ;;;
-;;;	  ǽ resume Ȥե̾äΤǤEmacs 19 Υǥ
-;;;	쥯ȥ resume.el Ȥե뤬äƥåޤ
-;;;	ϥޥɥ饤ǲ emacs ǤäƤ⡢˵ưƤ 
-;;;	emacs ˥եϤȤ(ԡ)ץǡ֤ɤ 
-;;;	resume ͤפȸʤޤ revive.el ˥͡
-;;;	षޤޤäsaveconf Ǥ desktop Ǥʤʤ
-;;;	ɥʬ֤򥵥ݡȤȸΤˡġʤƤ
-;;;	ϱѸǤˤϽ񤱤ʤ:-)
+;;;	  ŏ resume Ƃt@ĈłAEmacs 19 ̃fB
+;;;	Ng resume.el Ƃt@CăVbN󂯂܂B
+;;;	̓R}hCŉ emacs ƑłĂAɋNĂ 
+;;;	emacs Ƀt@CnƂ(s[[)vOŁuǂ 
+;;;	resume ˂vƌȂ܂䖝 revive.el Ƀl[
+;;;	܂B܂Asaveconf ł desktop łȂȂ
+;;;	EBhEԂ̕T|[gƌ̂ɁcAȂĂ
+;;;	͉płɂ͏Ȃ:-)B
 ;;;
-;;;ڼ갷
+;;;y舵z
 ;;;
-;;;	  Υץϡե꡼եȥȤޤΥץ
-;;;	Ѥʤ̤ФƤԤϰڤǤ
-;;;	ΤȤޤȤХݡȤ礤˴ޤ
-;;;	ڤˤϢϢϰʲΥɥ쥹ޤǤꤤ
-;;;	(2003/6)
+;;;	  ̃vÓAt[\tgEFAƂ܂B̃vO
+;;;	gpĐȂ錋ʂɑ΂Ă҂͈؂̐ӔC𕉂
+;;;	̂Ƃ܂ARgoO|[g͑傢Ɋ}
+;;;	BCyɂABA͈ȉ̃AhX܂ł肢
+;;;	(2003/6)B
 ;;;							yuuji@gentei.org
 
 (defconst revive:version
-  "$Id: revive.el,v 2.18 2003/06/22 05:11:46 yuuji Exp $"
+  "$Id: revive.el,v 2.18 2003/06/22 05:11:46 yuuji Exp yuuji $"
   "Version of revive.el")
 
 (defconst revive:version-prefix ";;;")
@@ -872,7 +872,7 @@ Configuration should be saved by save-current-configuration."
 (defun revive:mpg123 ()
   "Restore mpg123-mode's buffer."
   (interactive)
-  (let (d (cdr (assq 'default-directory (revive:prop-varlist x))))
+  (let ((d (cdr (assq 'default-directory (revive:prop-varlist x)))))
     (if (and d (file-directory-p d))
 	(progn
 	  (require 'mpg123)
@@ -891,7 +891,7 @@ Configuration should be saved by save-current-configuration."
 (provide 'revive)
 
 
-;; $Id: revive.el,v 2.18 2003/06/22 05:11:46 yuuji Exp $
+;; $Id: revive.el,v 2.18 2003/06/22 05:11:46 yuuji Exp yuuji $
 ;; $Log: revive.el,v $
 ;; Revision 2.18  2003/06/22 05:11:46  yuuji
 ;; revive:c-set-style disabled.
