@@ -1,8 +1,8 @@
 ;;; -*- Emacs-Lisp -*-
 ;;; Window manager for GNU Emacs.
-;;; $Id: windows.el,v 2.39 2003/03/28 11:34:41 yuuji Exp $
-;;; (c) 1993-2002 by HIROSE Yuuji [yuuji@gentei.org]
-;;; Last modified Fri Mar 28 20:30:41 2003 on firestorm
+;;; $Id: windows.el,v 2.40 2004/10/30 07:18:29 yuuji Exp yuuji $
+;;; (c) 1993-2005 by HIROSE Yuuji [yuuji@gentei.org]
+;;; Last modified Sun Sep 18 23:55:55 2005 on firestorm
 
 ;;;		Window manager for GNU Emacs
 ;;;
@@ -650,6 +650,8 @@ Not only with `C-c C-w 1' but also with `C-c 1'.")
   "*Default local configuration file")
 (defvar win:make-backup-files t
   "*Create a backup of window configuration file or not")
+(defvar win:config-loaded nil
+  "Flag if some configuration file is loaded or not")
 
 ;;Variables for Emacs 19
 (defvar win:no-raise-at-save nil
@@ -1519,7 +1521,7 @@ Do not call this function."
 ;; Functions for resume.
 ;;;
 (defconst win:revision
-  "$Revision: 2.39 $"
+  "$Revision: 2.40 $"
   "Revision string of windows.el")
 (defvar win:revision-prefix ";win;")
 
@@ -1648,6 +1650,7 @@ Configuration to be saved is a list of
 	(win:switch-window arg nil t))
     (win:set-frame-configuration config)
     (win:store-config win:current-config)
+    (setq win:config-loaded t)
     (win:switch-window arg)))
 
 ;;;###autoload
@@ -1752,7 +1755,8 @@ Non-nil for optional argument PRESERVE keeps all current buffers."
       (win:restore-buffer-list (car (car wconflist)))
       (setq wconflist (cdr wconflist)))
     (win:set-wc win:current-config)
-    (win:update-mode-line win:current-config))
+    (win:update-mode-line win:current-config)
+    (setq win:config-loaded t))
   (message "Finish loading.  Resume in window [%d]" win:current-config))
 
 (or global-mode-string (setq global-mode-string '("")))
@@ -2055,7 +2059,7 @@ CONF is the window configuration at the time.")
     (aset win:names-prefix goal prefix)
     (win:switch-menu-prepare-menu)
     (goto-char (point-min))
-    (search-forward (concat "(" (format "%d" goal) ")"))
+    (search-forward (concat "(" (format "%c" (+ goal win:base-key)) ")"))
     (beginning-of-line)
   ))
 
@@ -2225,6 +2229,9 @@ If interactive argument KILL is non-nil, kill menu buffer and no select."
 (run-hooks 'win-load-hook)
 
 ;; $Log: windows.el,v $
+;; Revision 2.40  2004/10/30 07:18:29  yuuji
+;; New flag win:config-loaded introduced for external utility.
+;;
 ;; Revision 2.39  2003/03/28 11:34:41  yuuji
 ;; add-hook alternative definition for Emacs-18(Nemacs)
 ;;
